==> lambda-1.60.0-sources.jar: software/amazon/awscdk/services/lambda/CfnVersionProps.java <==
package software.amazon.awscdk.services.lambda;

/**
 * Properties for defining a `AWS::Lambda::Version`.
 * <p>
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lambda-version.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.299Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.$Module.class, fqn = "@aws-cdk/aws-lambda.CfnVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Lambda::Version.FunctionName`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lambda-version.html#cfn-lambda-version-functionname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getFunctionName();

    /**
     * `AWS::Lambda::Version.CodeSha256`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lambda-version.html#cfn-lambda-version-codesha256
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCodeSha256() {
        return null;
    }

    /**
     * `AWS::Lambda::Version.Description`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lambda-version.html#cfn-lambda-version-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return null;
    }

    /**
     * `AWS::Lambda::Version.ProvisionedConcurrencyConfig`.
     * <p>
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lambda-version.html#cfn-lambda-version-provisionedconcurrencyconfig
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getProvisionedConcurrencyConfig() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnVersionProps> {
        private java.lang.String functionName;
        private java.lang.String codeSha256;
        private java.lang.String description;
        private java.lang.Object provisionedConcurrencyConfig;

        /**
         * Sets the value of {@link CfnVersionProps#getFunctionName}
         * @param functionName `AWS::Lambda::Version.FunctionName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionName(java.lang.String functionName) {
            this.functionName = functionName;
            return this;
        }

        /**
         * Sets the value of {@link CfnVersionProps#getCodeSha256}
         * @param codeSha256 `AWS::Lambda::Version.CodeSha256`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder codeSha256(java.lang.String codeSha256) {
            this.codeSha256 = codeSha256;
            return this;
        }

        /**
         * Sets the value of {@link CfnVersionProps#getDescription}
         * @param description `AWS::Lambda::Version.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link CfnVersionProps#getProvisionedConcurrencyConfig}
         * @param provisionedConcurrencyConfig `AWS::Lambda::Version.ProvisionedConcurrencyConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder provisionedConcurrencyConfig(software.amazon.awscdk.core.IResolvable provisionedConcurrencyConfig) {
            this.provisionedConcurrencyConfig = provisionedConcurrencyConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnVersionProps#getProvisionedConcurrencyConfig}
         * @param provisionedConcurrencyConfig `AWS::Lambda::Version.ProvisionedConcurrencyConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder provisionedConcurrencyConfig(software.amazon.awscdk.services.lambda.CfnVersion.ProvisionedConcurrencyConfigurationProperty provisionedConcurrencyConfig) {
            this.provisionedConcurrencyConfig = provisionedConcurrencyConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnVersionProps build() {
            return new Jsii$Proxy(functionName, codeSha256, description, provisionedConcurrencyConfig);
        }
    }

    /**
     * An implementation for {@link CfnVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVersionProps {
        private final java.lang.String functionName;
        private final java.lang.String codeSha256;
        private final java.lang.String description;
        private final java.lang.Object provisionedConcurrencyConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.functionName = this.jsiiGet("functionName", java.lang.String.class);
            this.codeSha256 = this.jsiiGet("codeSha256", java.lang.String.class);
            this.description = this.jsiiGet("description", java.lang.String.class);
            this.provisionedConcurrencyConfig = this.jsiiGet("provisionedConcurrencyConfig", java.lang.Object.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String functionName, final java.lang.String codeSha256, final java.lang.String description, final java.lang.Object provisionedConcurrencyConfig) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.functionName = java.util.Objects.requireNonNull(functionName, "functionName is required");
            this.codeSha256 = codeSha256;
            this.description = description;
            this.provisionedConcurrencyConfig = provisionedConcurrencyConfig;
        }

        @Override
        public java.lang.String getFunctionName() {
            return this.functionName;
        }

        @Override
        public java.lang.String getCodeSha256() {
            return this.codeSha256;
        }

        @Override
        public java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public java.lang.Object getProvisionedConcurrencyConfig() {
            return this.provisionedConcurrencyConfig;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("functionName", om.valueToTree(this.getFunctionName()));
            if (this.getCodeSha256() != null) {
                data.set("codeSha256", om.valueToTree(this.getCodeSha256()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getProvisionedConcurrencyConfig() != null) {
                data.set("provisionedConcurrencyConfig", om.valueToTree(this.getProvisionedConcurrencyConfig()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-lambda.CfnVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVersionProps.Jsii$Proxy that = (CfnVersionProps.Jsii$Proxy) o;

            if (!functionName.equals(that.functionName)) return false;
            if (this.codeSha256 != null ? !this.codeSha256.equals(that.codeSha256) : that.codeSha256 != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            return this.provisionedConcurrencyConfig != null ? this.provisionedConcurrencyConfig.equals(that.provisionedConcurrencyConfig) : that.provisionedConcurrencyConfig == null;
        }

        @Override
        public int hashCode() {
            int result = this.functionName.hashCode();
            result = 31 * result + (this.codeSha256 != null ? this.codeSha256.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.provisionedConcurrencyConfig != null ? this.provisionedConcurrencyConfig.hashCode() : 0);
            return result;
        }
    }
}

==> lambda-1.93.0-sources.jar: software/amazon/awscdk/services/lambda/CfnVersionProps.java <==
package software.amazon.awscdk.services.lambda;

/**
 * Properties for defining a `AWS::Lambda::Version`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.551Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.$Module.class, fqn = "@aws-cdk/aws-lambda.CfnVersionProps")
@software.amazon.jsii.Jsii.Proxy(CfnVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::Lambda::Version.FunctionName`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getFunctionName();

    /**
     * `AWS::Lambda::Version.CodeSha256`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getCodeSha256() {
        return null;
    }

    /**
     * `AWS::Lambda::Version.Description`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return null;
    }

    /**
     * `AWS::Lambda::Version.ProvisionedConcurrencyConfig`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getProvisionedConcurrencyConfig() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnVersionProps> {
        private java.lang.String functionName;
        private java.lang.String codeSha256;
        private java.lang.String description;
        private java.lang.Object provisionedConcurrencyConfig;

        /**
         * Sets the value of {@link CfnVersionProps#getFunctionName}
         * @param functionName `AWS::Lambda::Version.FunctionName`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder functionName(java.lang.String functionName) {
            this.functionName = functionName;
            return this;
        }

        /**
         * Sets the value of {@link CfnVersionProps#getCodeSha256}
         * @param codeSha256 `AWS::Lambda::Version.CodeSha256`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder codeSha256(java.lang.String codeSha256) {
            this.codeSha256 = codeSha256;
            return this;
        }

        /**
         * Sets the value of {@link CfnVersionProps#getDescription}
         * @param description `AWS::Lambda::Version.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link CfnVersionProps#getProvisionedConcurrencyConfig}
         * @param provisionedConcurrencyConfig `AWS::Lambda::Version.ProvisionedConcurrencyConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder provisionedConcurrencyConfig(software.amazon.awscdk.core.IResolvable provisionedConcurrencyConfig) {
            this.provisionedConcurrencyConfig = provisionedConcurrencyConfig;
            return this;
        }

        /**
         * Sets the value of {@link CfnVersionProps#getProvisionedConcurrencyConfig}
         * @param provisionedConcurrencyConfig `AWS::Lambda::Version.ProvisionedConcurrencyConfig`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder provisionedConcurrencyConfig(software.amazon.awscdk.services.lambda.CfnVersion.ProvisionedConcurrencyConfigurationProperty provisionedConcurrencyConfig) {
            this.provisionedConcurrencyConfig = provisionedConcurrencyConfig;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnVersionProps build() {
            return new Jsii$Proxy(functionName, codeSha256, description, provisionedConcurrencyConfig);
        }
    }

    /**
     * An implementation for {@link CfnVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnVersionProps {
        private final java.lang.String functionName;
        private final java.lang.String codeSha256;
        private final java.lang.String description;
        private final java.lang.Object provisionedConcurrencyConfig;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.functionName = software.amazon.jsii.Kernel.get(this, "functionName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.codeSha256 = software.amazon.jsii.Kernel.get(this, "codeSha256", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.provisionedConcurrencyConfig = software.amazon.jsii.Kernel.get(this, "provisionedConcurrencyConfig", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String functionName, final java.lang.String codeSha256, final java.lang.String description, final java.lang.Object provisionedConcurrencyConfig) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.functionName = java.util.Objects.requireNonNull(functionName, "functionName is required");
            this.codeSha256 = codeSha256;
            this.description = description;
            this.provisionedConcurrencyConfig = provisionedConcurrencyConfig;
        }

        @Override
        public final java.lang.String getFunctionName() {
            return this.functionName;
        }

        @Override
        public final java.lang.String getCodeSha256() {
            return this.codeSha256;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.lang.Object getProvisionedConcurrencyConfig() {
            return this.provisionedConcurrencyConfig;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("functionName", om.valueToTree(this.getFunctionName()));
            if (this.getCodeSha256() != null) {
                data.set("codeSha256", om.valueToTree(this.getCodeSha256()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getProvisionedConcurrencyConfig() != null) {
                data.set("provisionedConcurrencyConfig", om.valueToTree(this.getProvisionedConcurrencyConfig()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-lambda.CfnVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnVersionProps.Jsii$Proxy that = (CfnVersionProps.Jsii$Proxy) o;

            if (!functionName.equals(that.functionName)) return false;
            if (this.codeSha256 != null ? !this.codeSha256.equals(that.codeSha256) : that.codeSha256 != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            return this.provisionedConcurrencyConfig != null ? this.provisionedConcurrencyConfig.equals(that.provisionedConcurrencyConfig) : that.provisionedConcurrencyConfig == null;
        }

        @Override
        public final int hashCode() {
            int result = this.functionName.hashCode();
            result = 31 * result + (this.codeSha256 != null ? this.codeSha256.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.provisionedConcurrencyConfig != null ? this.provisionedConcurrencyConfig.hashCode() : 0);
            return result;
        }
    }
}
